==> auto-ui-2.1.28.tgz: package/es/radio/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import IconCheck from '../icon/check';
import './style.scss';
var Radio = function (props) {
    var checked = props.checked, disabled = props.disabled, className = props.className, text = props.text, onChange = props.onChange, hollow = props.hollow, otherProps = __rest(props, ["checked", "disabled", "className", "text", "onChange", "hollow"]);
    var composeClassName = cn('x-radio', {
        'x-radio--checked': checked,
        'x-radio--disabled': disabled,
        'x-radio--hollow': hollow,
    }, className);
    var onClick = function () {
        if (disabled) {
            return;
        }
        if (onChange) {
            onChange(!checked);
        }
    };
    if (onChange) {
        return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: onClick }),
            React.createElement("i", { className: "x-radio__icon" },
                React.createElement(IconCheck, null)),
            !!text && React.createElement("span", { className: "x-radio__text" }, text)));
    }
    return (React.createElement("span", __assign({}, otherProps, { className: composeClassName, onClick: onClick }),
        React.createElement("i", { className: "x-radio__icon" },
            React.createElement(IconCheck, null)),
        !!text && React.createElement("span", { className: "x-radio__text" }, text)));
};
export default Radio;

==> auto-ui-2.1.54.tgz: package/es/radio/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import cn from 'classnames';
import * as React from 'react';
import IconCheck from '../icon/check';
import './style.scss';
var Radio = function (props) {
    var checked = props.checked, disabled = props.disabled, className = props.className, text = props.text, onChange = props.onChange, hollow = props.hollow, otherProps = __rest(props, ["checked", "disabled", "className", "text", "onChange", "hollow"]);
    var composeClassName = cn('x-radio', {
        'x-radio--checked': checked,
        'x-radio--disabled': disabled,
        'x-radio--hollow': hollow,
    }, className);
    var onClick = function () {
        if (disabled) {
            return;
        }
        if (onChange) {
            onChange(!checked);
        }
    };
    if (onChange) {
        return (React.createElement("button", __assign({}, otherProps, { className: composeClassName, onClick: onClick }),
            React.createElement("i", { className: "x-radio__icon" },
                React.createElement(IconCheck, null)),
            !!text && React.createElement("span", { className: "x-radio__text" }, text)));
    }
    return (React.createElement("span", __assign({}, otherProps, { className: composeClassName, onClick: onClick }),
        React.createElement("i", { className: "x-radio__icon" },
            React.createElement(IconCheck, null)),
        !!text && React.createElement("span", { className: "x-radio__text" }, text)));
};
export default Radio;
